
TODO: TODO_19_67_22_89: remove `ignored_func_ids_list`

Instead, load unmapped `func_id`-s as `FuncState.fs_unplugged`.

There should be a place in the tree where these `func_id`-s should be plugged into.
Another `CompositeNodeType`?
Or maybe:
TODO: TODO_62_75_33_41: do not hardcode `plugin_instance_id`
      Combine it and use special interp which allows selecting function not within a func tree
      but trivially from a list. Then use config where this plugin instance id is registered
      as handler of unmapped `func_id`-s.
